@@ -9,14 +9,21 @@ function(train,test,ratio){
 		weight[i] = ratio*(1-ratio)^(i-1)/(1-(1-ratio)^n)
 	}
 	
-	if(is.vector(test) == TRUE){
-	
-		test.mat = t(as.matrix(test))
-		
-	}else{
-	
-		test.mat = test
-	}
+    if(is.vector(test) == TRUE){
+        
+        if(dim(train)[2] - 1 == 1){
+            # d = 1 case
+            test.mat = as.matrix(test)
+            
+        }else{
+            # d > 1 case
+            test.mat = t(as.matrix(test))
+        }
+        
+    }else{
+        
+        test.mat = test
+    }
 	
 	if(dim(test.mat)[2] != (dim(train)[2]-1)) stop("training data and test data have different dimensions")	
 	
